Struct amazon_sp_product_fees::models::fee_detail::FeeDetail
source · [−]pub struct FeeDetail {
pub fee_type: String,
pub fee_amount: Box<MoneyType>,
pub fee_promotion: Option<Box<MoneyType>>,
pub tax_amount: Option<Box<MoneyType>>,
pub final_fee: Box<MoneyType>,
pub included_fee_detail_list: Option<Vec<IncludedFeeDetail>>,
}Expand description
FeeDetail : The type of fee, fee amount, and other details.
Fields
fee_type: StringThe type of fee charged to a seller.
fee_amount: Box<MoneyType>fee_promotion: Option<Box<MoneyType>>tax_amount: Option<Box<MoneyType>>final_fee: Box<MoneyType>included_fee_detail_list: Option<Vec<IncludedFeeDetail>>A list of other fees that contribute to a given fee.
Implementations